pub struct NulTerminated<'a, T: Zero> { /* private fields */ }Expand description
An iterator over a nul-terminated buffer.
This is intended to allow safe, ergonomic iteration over C-style byte and wide strings without first having to read through the string and construct a slice. Assuming the safety requirements are upheld when constructing the iterator, it allows for string iteration in safe Rust.
Implementations
Sourceimpl<'a, T: Zero> NulTerminated<'a, T>
impl<'a, T: Zero> NulTerminated<'a, T>
Sourcepub unsafe fn new(ptr: *const T) -> Option<Self>
pub unsafe fn new(ptr: *const T) -> Option<Self>
Constructs a new iterator, starting at ptr, yielding elements of
type &T up to (but not including) the terminating nul.
The iterator returns None after the terminating nul has been
encountered.
Safety
The provided pointer must be a valid pointer to a buffer of contiguous
elements of type T, and the value 0 must be present within the
buffer at or after ptr (not necessarily at the end). The buffer must
not be written to for the lifetime of the iterator.