pub struct SrcDstPtrIter<'a, I: Iterator, U: Copy> { /* private fields */ }Expand description
A zipped iterator mapping an input iterator to an “out” pointer.
This is intended to allow safe, iterative writing to an “out pointer”. Special care needs to be taken to avoid creating references past the end of the output buffer, thus the output is zipped with an “input” iterator to ensure up-front control of the range of memory on which we create references.
Implementations
Sourceimpl<'a, I: Iterator, U: Copy> SrcDstPtrIter<'a, I, U>
impl<'a, I: Iterator, U: Copy> SrcDstPtrIter<'a, I, U>
Sourcepub unsafe fn new(iter: I, ptr: *mut U) -> Self
pub unsafe fn new(iter: I, ptr: *mut U) -> Self
Constructs a new iterator of “zipped” input and output.
The caller must provide an “input” iterator I and an “out pointer”
ptr. Assuming I has item type T, the new iterator will have
type Item = (T, &mut MaybeUninit<U>).
Safety
ptr must be a valid pointer to a writable buffer of contiguous (but
possibly uninitialized) elements of type U. The caller must ensure
that I does not return Some any more times than there are elements
in the output buffer. The caller must ensure that the iterator has
exclusive access to that buffer for the entire lifetime of the
iterator.